@@ -4,7 +4,6 @@ Definition for an RPC channel protocol on top of a websocket - enabling bi-direc
 import asyncio
 from inspect import _empty, getmembers, ismethod, signature
 from typing import Any, Coroutine, Dict, List
-from asyncio.coroutines import coroutine
 
 from pydantic import ValidationError
 
@@ -61,7 +60,7 @@ class RpcPromise:
 
     def set(self):
         """
-        Signal compeltion of request with received response
+        Signal completion of request with received response
         """
         self._event.set()
 
@@ -132,7 +131,7 @@ class RpcChannel:
             methods (RpcMethodsBase): RPC methods to expose to other side
             socket: socket object providing simple send/recv methods
             channel_id (str, optional): uuid for channel. Defaults to None in which case a random UUID is generated.
-            default_response_timeout(int, optional) default timeout for RPC call responses. Defaults to None - i.e. no timeout
+            default_response_timeout(float, optional) default timeout for RPC call responses. Defaults to None - i.e. no timeout
             sync_channel_id(bool, optional) should get the other side of the channel id, helps to identify connections, cost a bit networking time.
                 Defaults to False - i.e. not getting the other side channel id
         """
@@ -158,7 +157,7 @@ class RpcChannel:
         # convenience caller
         # TODO - pass remote methods object to support validation before call
         self.other = RpcCaller(self)
-        # core event callback regsiters
+        # core event callback registers
         self._connect_handlers: List[OnConnectCallback] = []
         self._disconnect_handlers: List[OnDisconnectCallback] = []
         self._error_handlers = []
@@ -288,7 +287,7 @@ class RpcChannel:
             return self._other_channel_id
 
     async def on_disconnect(self):
-        # disconnect happend - mark the channel as closed
+        # disconnect happened - mark the channel as closed
         self._closed.set()
         await self.on_handler_event(self._disconnect_handlers, self)
 
@@ -350,7 +349,7 @@ class RpcChannel:
         Wait on a previously made call
         Args:
             promise (RpcPromise): the awaitable-wrapper returned from the RPC request call
-            timeout (int, None, or DEFAULT_TIMEOUT): the timeout to wait on the response, defaults to DEFAULT_TIMEOUT.
+            timeout (float, None, or DEFAULT_TIMEOUT): the timeout to wait on the response, defaults to DEFAULT_TIMEOUT.
                 - DEFAULT_TIMEOUT - use the value passed as 'default_response_timeout' in channel init
                 - None - no timeout
                 - a number - seconds to wait before timing out
@@ -361,7 +360,7 @@ class RpcChannel:
         if timeout is DEFAULT_TIMEOUT:
             timeout = self.default_response_timeout
         # wait for the promise or until the channel is terminated
-        _, pending = await asyncio.wait([promise.wait(), self._closed.wait()], timeout=timeout, return_when=asyncio.FIRST_COMPLETED)
+        _, pending = await asyncio.wait([asyncio.ensure_future(promise.wait()), asyncio.ensure_future(self._closed.wait())], timeout=timeout, return_when=asyncio.FIRST_COMPLETED)
         # Cancel all pending futures and then detect if close was the first done
         for fut in pending:
             fut.cancel()
